

function decodeLEDType(value) {
    var text = "";

    switch(value & 0x07) {  // no bit shift needed
        case(0x0):
            text = "Power";
            break;
        case(0x1):
            text = "Run";
            break;
        case(0x2):
            text = "Attention";
            break;
        case(0x3):
            text = "Fault";
            break;
        case(0x4):
            text = "Identify";
            break;
        default:
            text = "Reserved";
            break;
    }

    return(text);
}

function decodeLEDColor(value) {
    var text = "";

    switch((value & 0xc0) >>> 6) {  // 0 fill right bit shift
        case(0x0):
            text = "Off";
            break;
        case(0x1):
            text = "Steady";
            break;
        case(0x2):
            text = "Blinking";
            break;
        default:
            text = "Reserved";
            break;
    }

    // color is irrelevant if light is off
    // also include a space before the color
    if(text != "Off") {
        switch((value & 0x38) >>> 3) {  // 0 fill right bit shift
            case(0x0):
                text += " red";
                break;
            case(0x1):
                text += " yellow";
                break;
            case(0x2):
                text += " green";
                break;
            case(0x3):
                text += " blue";
                break;
            default:
                text += " reserved";
                break;
        }
    }

    return(text);
}

function kludgeDecodeLEDType(value) {
    var text = "";

    switch(value & 0x07) {  // no bit shift needed
        case(0x0):
            text = "Power";
            break;
        case(0x1):
            text = "Run";
            break;
        case(0x2):
            text = "";
            break;
        case(0x3):
            text = "Fault";
            break;
        case(0x4):
            text = "Identify";
            break;
       default:
            text = "Reserved";
            break;
    }

    return(text);
}


function kludgeDecodeLEDColor(value) {
    var text = "";

    switch((value & 0xc0) >>> 6) {  // 0 fill right bit shift
        case(0x0):
            text = "Off";
            break;
        case(0x1):
            text = "On";
            break;
        case(0x2):
            text = "Blinking";
            break;
        default:
            text = "Reserved";
            break;
    }

    // color is irrelevant if light is off
    // also include a space before the color
    if(text != "Off") {
        switch((value & 0x38) >>> 3) {  // 0 fill right bit shift
            case(0x0):
                text += " red";
                break;
            case(0x1):
                text += " ";
                break;
            case(0x2):
                text += " green";
                break;
            case(0x3):
                text += " blue";
                break;
            default:
                text += " reserved";
                break;
        }
    }

    return(text);
}

/****************************************************************/

function eliminate_hardreturn(rawString)
{

 for (movingptr = 0; movingptr < rawString.length; movingptr++)
        {
                // some bad characters won't supported by Netscape, so convert them to space
                if (rawString[movingptr] < 32)
                        rawString[movingptr] = 32;
        }
}

// check fault tolerant fans group redundancy
// receives an array with all cpqHeFltTolFanEntry belonging to the group
// return 1 (N/A)
//        2 (Not Redundant)
//        3 (Redundant)
function fanGroupRedundancy(groupArray)
{
	var arraySize = 0;
	var allFansAbsent = true;
	var existRedundantFan = false;
	var lGroupArray = groupArray;
	
	// verify array size - don't use the length property since lGroupArray
	// may be a sparse array
	if (typeof(lGroupArray) == "object")
	{
		for (var i = 0; i < lGroupArray.length; i++)
		{
			if (typeof(lGroupArray[i]) != "undefined")
			{
				// fans in group 0 are singletons
				if (lGroupArray[i].cpqHeFltTolFanRedundantPartner == 0)
				{
					return 1;
				}
				// verify if all fans in the group are absent
				if ((lGroupArray[i].cpqHeFltTolFanPresent == 3) && allFansAbsent)
				{
					allFansAbsent = false;
				}
				// verify if there is a redundant fan in the group
				if ((lGroupArray[i].cpqHeFltTolFanRedundant == 3) && !existRedundantFan)
				{
					existRedundantFan = true;
				}
				arraySize++;
			}			
		}
	}
	
	// groups with one member or with all fans absent have redundancy N/A
	// (according to TT#1000300563 - Show Group Redundancy Status Icon)
	if ((arraySize <= 1) || allFansAbsent)
	{
		return 1;
	}
	else if (existRedundantFan)
	{
		return 3;
	}
	else
	{
		return 2;
	}
}


// verify the redundancy of all fault tolerant fan groups in order to
// determine the overall condition - uses function fanGroupRedundancy
// receives table cpqHeFltTolFanEntry
// returns the following conditions:
// - Degraded (3) if there's at least 1 not redundant fan group
// - OK (2) otherwise
function faultTolFansCondition(faulTolFanTable)
{
	var lFaulTolFanTable = faulTolFanTable;

	// group the fans
	var fanGroup = new Array();
	var thisFan, currGroup, currFan;
	for(var i = 0; i < lFaulTolFanTable.length; i++)
	{
		thisFan = lFaulTolFanTable[i];
		currGroup = thisFan.cpqHeFltTolFanRedundantPartner;
		currFan = thisFan.cpqHeFltTolFanIndex;
		if (typeof(fanGroup[currGroup]) == "undefined")
		{
			fanGroup[currGroup] = new Array();
		}
		fanGroup[currGroup][currFan] = new Object();
		fanGroup[currGroup][currFan] = thisFan;
	}
	
	// verify groups redundancy, if a non redundant group was found,
	// return condition "Degraded"
	for (var i = 0; i < fanGroup.length; i++)
	{
		if (typeof(fanGroup[i]) != "undefined")
		{
			if (fanGroupRedundancy(fanGroup[i]) == 2)
			{
				return 3;
			}
		}
	}
	
	// if no non-redundant fan was found, return condition "OK"
	return 2;
}


// check power supply group redundancy
// receives an array with all cpqHeFltTolPowerSupplyEntry belonging to the group
// return 1 (N/A)
//        2 (Not Redundant)
//        3 (Redundant)
function powerGroupRedundancy(groupArray)
{
	var arraySize = 0;
	var allPowersAbsent = true;
	var existRedundantPower = false;
	var lGroupArray = groupArray;
	
	// verify array size - don't use the length property since lGroupArray
	// may be a sparse array
	if (typeof(lGroupArray) == "object")
	{
		for (var i = 0; i < lGroupArray.length; i++)
		{
			if (typeof(lGroupArray[i]) != "undefined")
			{
				// power supplies in group 0 are singletons
				if (lGroupArray[i].cpqHeFltTolPowerSupplyRedundantPartner == 0)
				{
					return 1;
				}
				// verify if all power supplies in the group are absent
				if ((lGroupArray[i].cpqHeFltTolPowerSupplyPresent == 3) && allPowersAbsent)
				{
					allPowersAbsent = false;
				}
				// verify if there is a redundant power supply in the group
				if ((lGroupArray[i].cpqHeFltTolPowerSupplyRedundant == 3) && !existRedundantPower)
				{
					existRedundantPower = true;
				}
				arraySize++;
			}			
		}
	}
	
	// groups with one member or with all power supplies absent have redundancy N/A
	// (according to CR035 - Add Power Supply Group Redundancy Icon)
	if ((arraySize <= 1) || allPowersAbsent)
	{
		return 1;
	}
	else if (existRedundantPower)
	{
		return 3;
	}
	else
	{
		return 2;
	}
}


// verify the redundancy of all powers supply groups in order to
// determine the overall condition - uses function powerGroupRedundancy
// receives table cpqHeFltTolPowerSupplyEntry
// returns the following conditions:
// - Degraded (3) if there's at least 1 not redundant power supply group
// - OK (2) otherwise
function faultTolPowersCondition(faulTolPowerTable)
{
	var lFaulTolPowerTable = faulTolPowerTable;
	var powerSupCondition = new cpqCondition();

	// aggregate power supplies status
	for (var i = 0; i < lFaulTolPowerTable.length; i++)
	{
		powerSupCondition.update(lFaulTolPowerTable[i].cpqHeFltTolPowerSupplyCondition);
	}

	// if it is a cellular system, aggregate group redundancy
	if (isPartitionedSystem())
	{
		// group the power supplies
		var powerGroup = new Array();
		var thisPower, currGroup, currPower;
		for(var i = 0; i < lFaulTolPowerTable.length; i++)
		{
			thisPower = lFaulTolPowerTable[i];
			currGroup = thisPower.cpqHeFltTolPowerSupplyRedundantPartner;
			currPower = i;
			if (typeof(powerGroup[currGroup]) == "undefined")
			{
				powerGroup[currGroup] = new Array();
			}
			powerGroup[currGroup][currPower] = new Object();
			powerGroup[currGroup][currPower] = thisPower;
		}
		// if a non redundant group was found aggregate condition "Degraded"	
		for (var i = 0; i < powerGroup.length; i++)
		{
			if (typeof(powerGroup[i]) != "undefined")
			{
				if (powerGroupRedundancy(powerGroup[i]) == 2)
				{
					powerSupCondition.update(3);
					return powerSupCondition.state;
				}
			}
		}
		// if no non-redundant powers supply was found, return condition "OK"
		powerSupCondition.update(2);
	}
	
	return powerSupCondition.state;
}